/* ma1_logdsae.sas */
TITLE1 'Logarithms of spectral density,'; 
TITLE2 'of their estimates and confidence intervals';
TITLE3 'of MA(1)-process';

/* Generate MA(1)-process */
DATA data1;
  DO t=0 TO 160;
    e=RANNOR(1);
    y=e-.6*LAG(e);
    OUTPUT;
  END;

/* Estimation of spectral density */
PROC SPECTRA DATA=data1(FIRSTOBS=2) S OUT=data2;
  VAR y; WEIGHTS 1 3 6 9 12 15 18 20 21 21 21 20 18 15 12 9 6 3 1; 
  RUN;

/* Adjusting different definitions and computation of confidence bands */
DATA data3; SET data2;
  lambda=FREQ/(2*CONSTANT('PI'));
  log_s_01=LOG(S_01/2*4*CONSTANT('PI'));
  nu=2/(3763/53361);
  c1=log_s_01+LOG(nu)-LOG(CINV(.975,nu));
  c2=log_s_01+LOG(nu)-LOG(CINV(.025,nu));

/* Compute underlying spectral density */
DATA data4;
  DO l=0 TO .5 BY 0.01;
    log_f=LOG((1-1.2*COS(2*CONSTANT('PI')*l)+.36));
    OUTPUT;
  END;

/* Merge the data sets */
DATA data5;
  MERGE data3(KEEP=log_s_01 lambda c1 c2) data4;

/* Graphical options */
AXIS1 LABEL=NONE;
AXIS2 LABEL=(F=CGREEK 'l') ORDER=(0 TO .5 BY .1);
SYMBOL1 I=JOIN C=BLUE V=NONE L=1;
SYMBOL2 I=JOIN C=RED V=NONE L=2;
SYMBOL3 I=JOIN C=GREEN V=NONE L=33;

/* Plot underlying and estimated spectral density */
PROC GPLOT DATA=data5;
  PLOT log_f*l=1 log_s_01*lambda=2 c1*lambda=3 c2*lambda=3 / OVERLAY VAXIS=AXIS1 HAXIS=AXIS2;
RUN; QUIT;
