/* donauwoerth_dcheck1.sas */
TITLE1 'Theoretical process analysis';
TITLE2 'Donauwoerth Data';
/* Note that this program requires the file 'corrseasad' and 'seasad' generated by program donauwoerth_adjustment.sas */

/* Computation of theoretical autocorrelation */
PROC IML;
  PHI={1 -1.61943 0.63143};
  THETA={1 -0.34553 -0.34821 -0.10327};
  LAG=1000;
  CALL ARMACOV(COV, CROSS, CONVOL, PHI, THETA, LAG);
  N=1:1000;
  theocorr=COV/7.7685992485;
  CREATE autocorr23;
  APPEND;
QUIT;

PROC IML;
  PHI={1 -1.85383 1.04408 -0.17899};
  THETA={1 -0.58116 -0.23329};
  LAG=1000;
  CALL ARMACOV(COV, CROSS, CONVOL, PHI, THETA, LAG);
  N=1:1000;
  theocorr=COV/7.7608247812;
  CREATE autocorr32;
  APPEND;
QUIT;

%MACRO Simproc(p,q);

/* Graphical options */
SYMBOL1 V=NONE C=BLUE I=JOIN W=2;
SYMBOL2 V=DOT C=RED I=NONE H=0.3 W=1;
SYMBOL3 V=DOT C=RED I=JOIN L=2 H=1 W=2;
AXIS1 LABEL=(ANGLE=90 'Autocorrelations');
AXIS2 LABEL=('Lag') ORDER = (0 TO 500 BY 100);
AXIS3 LABEL=(ANGLE=90 'Partial Autocorrelations');
AXIS4 LABEL=('Lag') ORDER = (0 TO 50 BY 10);
LEGEND1 LABEL=NONE VALUE=('theoretical' 'empirical');

/* Comparison of theoretical and empirical autocorrelation */
DATA compare&p&q;
  MERGE autocorr&p&q(KEEP=N theocorr) corrseasad(KEEP=corr);
PROC GPLOT DATA=compare&p&q(OBS=500);
  PLOT theocorr*N=1 corr*N=2 / OVERLAY LEGEND=LEGEND1 VAXIS=AXIS1 HAXIS=AXIS2;
RUN;

/* Computing of theoretical partial autocorrelation */
PROC TRANSPOSE DATA=autocorr&p&q OUT=transposed&p&q PREFIX=CORR;
DATA pacf&p&q(KEEP=PCORR0-PCORR100);
  PCORR0=1;
  SET transposed&p&q(WHERE=(_NAME_='THEOCORR'));
  ARRAY CORRS(100) CORR2-CORR101;
  ARRAY PCORRS(100) PCORR1-PCORR100;
  ARRAY P(100) P1-P100;
  ARRAY w(100) w1-w100;
  ARRAY A(100) A1-A100;
  ARRAY B(100) B1-B100;
  ARRAY u(100) u1-u100;
  PCORRS(1)=CORRS(1);
  P(1)=1-(CORRS(1)**2);
    DO i=1 TO 100; B(i)=0; u(i)=0; END;
    DO j=2 TO 100;
      IF j > 2 THEN DO n=1 TO j-2; A(n)=B(n); END;
      A(j-1)=PCORRS(j-1);
      DO k=1 TO j-1; u(j)=u(j)-A(k)*CORRS(j-k); END;
      w(j)=u(j)+CORRS(j);
      PCORRS(j)=w(j)/P(j-1);
      P(j)=P(j-1)*(1-PCORRS(j)**2);
      DO m=1 TO j-1; B(m)=A(m)-PCORRS(j)*A(j-m); END;
    END;
PROC TRANSPOSE DATA=pacf&p&q OUT=plotdata&p&q(KEEP=PACF1) PREFIX=PACF;

/* Comparison of theoretical and empirical partial autocorrelation */
DATA compareplot&p&q;
  MERGE plotdata&p&q corrseasad(KEEP=partcorr LAG);
PROC GPLOT DATA=compareplot&p&q(OBS=50);
  PLOT PACF1*LAG=1 partcorr*LAG=3 / OVERLAY VAXIS=AXIS3 HAXIS=AXIS4 LEGEND=LEGEND1;
RUN;

%MEND;
%Simproc(2,3);
%Simproc(3,2);
QUIT;
