/* donauwoerth_firstanalysis.sas */
TITLE1 'First Analysis';
TITLE2 'Donauwoerth Data';

/* Read in data set */
DATA donau;
  INFILE '/scratch/perm/stat/daten/donauwoerth.txt';
  INPUT day month year discharge;
  date=MDY(month, day, year);
  FORMAT date mmddyy10.;
  
/* Compute mean */
PROC MEANS DATA=donau;
  VAR discharge;
RUN;

/* Graphical options */
SYMBOL1 V=DOT I=JOIN C=GREEN H=0.3 W=1;
AXIS1 LABEL=(ANGLE=90 'Discharge');
AXIS2 LABEL=('January 1985 to December 2004') ORDER=('01JAN85'd '01JAN89'd '01JAN93'd '01JAN97'd '01JAN01'd '01JAN05'd);
AXIS3 LABEL=(ANGLE=90 'Autocorrelation');
AXIS4 LABEL=('Lag') ORDER = (0 1000 2000 3000 4000 5000 6000 7000);
AXIS5 LABEL=('I(' F=CGREEK 'l)');
AXIS6 LABEL=(F=CGREEK 'l');

/* Generate data plot */
PROC GPLOT DATA=donau;
  PLOT discharge*date=1 / VREF=201.6 VAXIS=AXIS1 HAXIS=AXIS2;
RUN;

/* Compute and plot empirical autocorrelation */
PROC ARIMA DATA=donau;
  IDENTIFY VAR=discharge NLAG=7000 OUTCOV=autocorr NOPRINT;
PROC GPLOT DATA=autocorr;
  PLOT corr*lag=1 /VAXIS=AXIS3 HAXIS=AXIS4 VREF=0;
RUN;

/* Compute periodogram */
PROC SPECTRA DATA=donau COEF P OUT=data1;
  VAR discharge;

/* Adjusting different periodogram definitions */
DATA data2;
  SET data1(FIRSTOBS=2);
  p=P_01/2;
  lambda=FREQ/(2*CoNSTANT('PI'));
  DROP P_01 FREQ;

/* Plot periodogram */
PROC GPLOT DATA=data2(OBS=100);
  PLOT p*lambda=1 / VAXIS=AXIS5 HAXIS=AXIS6;
RUN;

/* Print three largest periodogram values */
PROC SORT DATA=data2 OUT=data3;  BY DESCENDING p;
PROC PRINT DATA=data3(OBS=3) NOOBS;
RUN; QUIT;