/* donauwoerth_forecasting.sas */
TITLE1 'Forecasting';
TITLE2 'Donauwoerth Data';

/* Note that this program requires the file 'seasad' generated by program donauwoerth_adjustment.sas */

/* Cut off the last 365 values */
DATA reduced;
  SET seasad(OBS=6935);
  N=_N_;

/* Estimate model coefficients from reduced sample */
PROC ARIMA DATA=reduced;
  IDENTIFY VAR=sa NLAG=300 NOPRINT;
  ESTIMATE METHOD=CLS p=2 q=3 OUTMODEL=model NOPRINT;
RUN;

/* One-step-forecasts of previous estimated model */
PROC ARIMA DATA=seasad;
  IDENTIFY VAR=sa NLAG=300 NOPRINT;
  ESTIMATE METHOD=CLS p=2 q=3 MU=-0.04928 AR=1.60880 -0.62077 MA=0.33764 0.35157 0.10282 NOEST NOPRINT;
  FORECAST LEAD=0 OUT=forecast NOPRINT;
RUN;

DATA forecast;
  SET forecast;
  lag=_N_;

DATA residual1(KEEP=residual lag);
  SET forecast(OBS=6935);

DATA residual2(KEEP=residual date);
  MERGE forecast(FIRSTOBS=6936) donau(FIRSTOBS=6936 KEEP=date);

DATA residual3(KEEP=residual lag);
  SET forecast(OBS=5170);

DATA residual4(KEEP=residual lag);
  SET forecast(OBS=5200);

/* Graphical options */
SYMBOL1 V=DOT C=GREEN I=JOIN H=0.5;
SYMBOL2 V=DOT I=JOIN H=0.4 C=BLUE W=1 L=1;
AXIS1 LABEL=('Index')
      ORDER=(4800 5000 5200);
AXIS2 LABEL=(ANGLE=90 'Estimated residual');
AXIS3 LABEL=('January 2004 to January 2005')
      ORDER=('01JAN04'd '01MAR04'd '01MAY04'd '01JUL04'd '01SEP04'd '01NOV04'd '01JAN05'd);
AXIS4 LABEL=(ANGLE=90 'Estimated forecast error');


/* Plot estimated residuals */
PROC GPLOT DATA=residual1(FIRSTOBS=4800);
  PLOT residual*lag=2 /HAXIS=AXIS1 VAXIS=AXIS2;
RUN;

/* Plot estimated forecast errors of best one-step forecasts */
PROC GPLOT DATA=residual2;
  PLOT residual*date=2 /HAXIS=AXIS3 VAXIS=AXIS4;
RUN;

/* Testing for white noise */
%MACRO wn(k);
PROC SPECTRA DATA=residual&k P WHITETEST OUT=periodo&k;
  VAR residual;
RUN;

/* Calculate the sum of the periodogram */
PROC MEANS DATA=periodo&k(FIRSTOBS=2) NOPRINT;
  VAR P_01;
  OUTPUT OUT=psum&k SUM=psum;
RUN;

/* Compute empirical distribution function of cumulated periodogram and its confidence bands */
DATA conf&k;
  SET periodo&k(FIRSTOBS=2);
  IF _N_=1 THEN SET psum&k;
  RETAIN s 0;
  s=s+P_01/psum;
  fm=_N_/(_FREQ_-1);
  yu_01=fm+1.63/SQRT(_FREQ_-1);
  yl_01=fm-1.63/SQRT(_FREQ_-1);
  yu_05=fm+1.36/SQRT(_FREQ_-1);
  yl_05=fm-1.36/SQRT(_FREQ_-1);

/* Graphical options */
SYMBOL3 V=NONE I=STEPJ C=GREEN;
SYMBOL4 V=NONE I=JOIN C=RED L=2;
SYMBOL5 V=NONE I=JOIN C=RED L=1;
AXIS5 LABEL=('x') ORDER=(.0 TO 1.0 BY .1);
AXIS6 LABEL=NONE;

/* Plot empirical distribution function of cumulated periodogram with its confidence bands */
PROC GPLOT DATA=conf&k;
  PLOT fm*s=3 yu_01*fm=4 yl_01*fm=4 yu_05*fm=5 yl_05*fm=5 / OVERLAY HAXIS=AXIS5 VAXIS=AXIS6;
RUN;
%MEND;

%wn(1);
%wn(2);

/* Merge estimated residuals and estimated forecast errors */
DATA residuals;
  MERGE residual1(KEEP=residual) residual2(KEEP=residual RENAME=(residual=forecasterror));
  
/* Compute standard deviations */
PROC MEANS DATA=residuals;
  VAR residual forecasterror;
RUN;

%wn(3);
%wn(4);

QUIT;
