/* population1.sas */
TITLE1 'Population sizes and logistic fit';
TITLE2 'Population1 Data';

/* Read in the data */
DATA data1;
INFILE 'c:\data\population1.txt';
INPUT year t pop;

/* Compute parameters for fitted logistic function */
PROC NLIN DATA=data1 OUTEST=estimate;
    MODEL pop=beta3/(1+beta2*EXP(-beta1*t));
    PARAMETERS beta1=1 beta2=1 beta3=20;
RUN;

/* Generate fitted logistic function */
DATA data2;
SET estimate(WHERE=(_TYPE_='FINAL'));
DO t1=0 TO 11 BY 0.2;
  f_log=beta3/(1+beta2*EXP(-beta1*t1));
  OUTPUT;
END;

/* Merge data sets */
DATA data3;
    MERGE data1 data2;

/* Graphical options */
AXIS1 LABEL=(ANGLE=90 'population in millions');
AXIS2 LABEL=('t');
SYMBOL1 V=DOT C=GREEN I=NONE;
SYMBOL2 V=NONE C=GREEN I=JOIN W=1;

/* Plot data with fitted function */
PROC GPLOT DATA=data3;
    PLOT pop*t=1 f_log*t1=2 / OVERLAY VAXIS=AXIS1 HAXIS=AXIS2;
RUN; QUIT;
