/* temperatures.sas */
TITLE1 'Original and seasonally adjusted data';
TITLE2 'Temperatures data';

/* Read in the data and generate SAS-formatted date */
DATA temperatures;
  INFILE 'c:\data\temperatures.txt';
  INPUT temperature;
  date=INTNX('month','01jan95'd,_N_-1);
  FORMAT date yymon.;

/* Make seasonal adjustment */
PROC TIMESERIES DATA=temperatures OUT=series SEASONALITY=12 OUTDECOMP=deseason;
  VAR temperature;
  DECOMP /MODE=ADD;

/* Merge necessary data for plot */
DATA plotseries;
  MERGE temperatures deseason(KEEP=SA);

/* Graphical options */
AXIS1 LABEL=(ANGLE=90 'temperatures');
AXIS2 LABEL=('Date');
SYMBOL1 V=DOT C=GREEN I=JOIN H=1 W=1;
SYMBOL2 V=STAR C=GREEN I=JOIN H=1 W=1;

/* Plot data and seasonally adjusted series */
PROC GPLOT data=plotseries;
  PLOT temperature*date=1 SA*date=2 /OVERLAY VAXIS=AXIS1 HAXIS=AXIS2;

RUN; QUIT;
