/* star_periodogram.sas */
TITLE1 'Periodogram';
TITLE2 'Star Data';

/* Read in the data */
DATA data1;
  INFILE 'c:\data\star.txt';
  INPUT lumen @@;

/* Compute the periodogram */
PROC SPECTRA DATA=data1 COEF P OUT=data2;
  VAR lumen;

/* Adjusting different periodogram definitions */
DATA data3;
  SET data2(FIRSTOBS=2);
  p=P_01/2; 
  lambda=FREQ/(2*CONSTANT('PI'));
  DROP P_01 FREQ;

/* Graphical options */
SYMBOL1 V=NONE C=GREEN I=JOIN;
AXIS1 LABEL=('I(' F=CGREEK 'l)');
AXIS2 LABEL=(F=CGREEK 'l');

/* Plot the periodogram */
PROC GPLOT DATA=data3(OBS=50);
  PLOT p*lambda=1 / VAXIS=AXIS1 HAXIS=AXIS2;

/* Sort by periodogram values */
PROC SORT DATA=data3 OUT=data4;
  BY DESCENDING p;

/* Print largest periodogram values */
PROC PRINT DATA=data2(OBS=1) NOOBS; 
  VAR COS_01;
PROC PRINT DATA=data4(OBS=6) NOOBS; 
RUN; QUIT;
