/* airline_kalman.sas */
TITLE1 'Original and Forecasted Data';
TITLE2 'Airline Data';

/* Read in the data and compute log-transformation */
DATA data1;
  INFILE 'c:\data\airline.txt';
  INPUT y;
  yl=LOG(y); 
  t=_N_;

/* Compute trend and seasonally adjusted data set */
PROC STATESPACE DATA=data1 OUT=data2 LEAD=12;
 VAR yl(1,12); ID t;

/* Compute forecasts by inverting the log-transformation */
DATA data3;
   SET data2; 
   yhat=EXP(FOR1);

/* Merge data sets */
DATA data4(KEEP=t y yhat);
   MERGE data1 data3;
   BY t;

/* Graphical options */
LEGEND1 LABEL=('') VALUE=('original' 'forecast');
SYMBOL1 C=BLACK V=DOT H=0.7 I=JOIN L=1;
SYMBOL2 C=BLACK V=CIRCLE H=1.5 I=JOIN L=1;
AXIS1 LABEL=(ANGLE=90 'Passengers');
AXIS2 LABEL=('January 1949 to December 1961');

/* Plot data and forecasts */
PROC GPLOT DATA=data4;
 PLOT y*t=1 yhat*t=2 / OVERLAY VAXIS=AXIS1 HAXIS=AXIS2 LEGEND=LEGEND1;
RUN; QUIT;
